@@ -1,12 +1,14 @@
 use std::path::Path;
 use tract_hir::prelude::*;
-use tract_pulse::WithPulse;
 
 use anyhow::{bail, format_err, Context, Result};
 use ffi_convert::{CReprOf, RawBorrow, RawPointerConverter};
 use std::cell::RefCell;
 use std::ffi::CString;
 
+mod loader;
+use loader::load_model;
+
 /// Borrowed from tract-cli with adapted npz type signature
 pub fn for_npz(
     npz: &mut ndarray_npy::NpzReader<std::io::Cursor<&[u8]>>,
@@ -153,19 +155,17 @@ macro_rules! get_typed_model_plan_from {
     }};
 }
 
-/// load simple tract Plan of TypedModel from NNEF
-pub fn call_load_plan_from_nnef_path(
-    dirpath_string: *const libc::c_char,
+/// load simple tract Plan of TypedModel from various serialization:
+/// NNEF: folder or tgz
+/// ONNX
+pub fn call_load_plan_from_path(
+    path_string: *const libc::c_char,
     plan_ptr: *mut *const CTypedModelPlan,
 ) -> Result<()> {
-    let nnef = tract_nnef::nnef().with_tract_core().with_pulse();
-    let dir_path = Path::new(create_rust_str_from!(dirpath_string));
-    let plan: TypedRunnableModel<TypedModel> = SimplePlan::new(
-        nnef.model_for_path(dir_path)
-            .map_err(|e| format_err!("Load NNEF model: {:?}", e))?
-            .into_decluttered()?
-            .into_optimized()?,
-    )?;
+    let path = Path::new(create_rust_str_from!(path_string));
+    let typed_model = load_model(path)?;
+    let plan: TypedRunnableModel<TypedModel> =
+        SimplePlan::new(typed_model.into_decluttered()?.into_optimized()?)?;
 
     let cplan = CTypedModelPlan(plan.into_raw_pointer() as _);
 
@@ -252,11 +252,11 @@ pub fn call_run_typed_model_plan(
 }
 
 #[no_mangle]
-pub unsafe extern "C" fn load_plan_from_nnef_path(
-    dirpath_string: *const libc::c_char,
+pub unsafe extern "C" fn load_plan_from_path(
+    path_string: *const libc::c_char,
     plan_ptr: *mut *const CTypedModelPlan,
 ) -> TractResult {
-    wrap(|| call_load_plan_from_nnef_path(dirpath_string, plan_ptr))
+    wrap(|| call_load_plan_from_path(path_string, plan_ptr))
 }
 
 #[no_mangle]
